@@ -1,5 +1,5 @@
 /*
- * $Id: config_var.c,v 1.5 2007/08/18 11:48:44 d1mag Exp $
+ * $Id: config_var.c,v 1.7 2007/10/12 12:46:48 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -227,6 +227,82 @@ int read_config_file(int modify_sensors)
       }
     } else
 #endif
+    if(!strncasecmp(t, "sensor_type", 11)) {
+      char rrdtype[FILENAME_LEN+1];
+      char datafile[FILENAME_LEN+1];
+      int minval = -40;
+      int maxval = 256;
+      int rrdtype_nr = 0;
+      t += 11;
+      while(*t && ((*t=='\t') || (*t==' '))) t++;
+      rc = sscanf(t, "%s", sens_id);
+      if(rc != 1) {
+	printf("can't find any sensor name [%s]\n", t);
+	goto error_parsing;
+      }
+      t += strlen(sens_id);
+      while(*t && ((*t=='\t') || (*t==' '))) t++;
+
+      rc = sscanf(t, "%s", datafile);
+      if(rc != 1) {
+	printf("can't find datafile argument\n");
+	goto error_parsing;
+      }
+
+      if(!(s=find_sensor_and_datafile(sens_id, datafile))) {
+	printf("can't find sensor [%s] [%s]\n", sens_id, datafile);
+	printf("create sensor before setting sensor_type\n");
+	goto error_parsing;
+      }
+
+      t += strlen(datafile);
+      while(*t && ((*t=='\t') || (*t==' '))) t++;
+
+      rc = sscanf(t, "%s", rrdtype);
+      if(rc != 1) {
+	printf("can't find any sensor rrdtype [%s]\n", t);
+	goto error_parsing;
+      }
+      if(!strcasecmp(rrdtype, "GAUGE"))
+	rrdtype_nr = 0;
+      else if(!strcasecmp(rrdtype, "COUNTER"))
+	rrdtype_nr = 1;
+      else if(!strcasecmp(rrdtype, "DERIVE"))
+	rrdtype_nr = 2;
+      else {
+	printf("Valid rrdtypes are GAUGE, COUNTER and DERIVE [%s]\n", t);
+	goto error_parsing;
+      }
+      t += strlen(rrdtype);
+      while(*t && ((*t=='\t') || (*t==' '))) t++;
+
+      if(*t) {
+	//printf("t=[%s]\n", t);
+	rc = sscanf(t, "min %d", &minval);
+	if(rc == 1) {
+	  t += 3;
+	  //printf("set minval = %d\n", minval);
+	  while(*t && ((*t=='\t') || (*t==' '))) t++;
+	  while(*t && ((*t!='\t') && (*t!=' '))) t++;
+	  while(*t && ((*t=='\t') || (*t==' '))) t++;
+	}
+      }
+      if(*t) {
+	//printf("t2=[%s]\n", t);
+	rc = sscanf(t, "max %d", &maxval);
+	if(rc == 1) {
+	  t += 3;
+	  //printf("set maxval = %d\n", maxval);
+	  while(*t && ((*t=='\t') || (*t==' '))) t++;
+	  while(*t && ((*t!='\t') && (*t!=' '))) t++;
+	  while(*t && ((*t=='\t') || (*t==' '))) t++;
+	}
+      }
+
+      s->rrdtype = rrdtype_nr;
+      s->minval = minval;
+      s->maxval = maxval;
+    } else
     if(!strncasecmp(t, "sensor", 6)) {
       char datafile[FILENAME_LEN+1];
       char rrdfile1[FILENAME_LEN+1];
@@ -470,7 +546,8 @@ int read_config_file(int modify_sensors)
       char rrdfile[FILENAME_LEN+1];
       char template1[FILENAME_LEN+1];
       char template2[FILENAME_LEN+1];
-      char *e;
+      char *e; 
+      struct rrd_file *r;
       //printf("t[7]=%c\n", t[7]);
       //printf("t=[%s]\n", t);
       t += 7;
@@ -501,7 +578,8 @@ int read_config_file(int modify_sensors)
 	printf("Expecting two templates for rrd-file [%s]\n", rrdfile);
 	goto error_parsing;
       }
-      if(!add_rrdfile(rrdfile, template1, template2, NULL)) {
+
+      if(!(r = add_rrdfile(rrdfile, template1, template2, NULL))) {
 	printf("Error setting template to [%s]\n", rrdfile);
 	exit(0);
       }
