@@ -1,5 +1,5 @@
 /*
- * $Id: temploggerd.c,v 1.10 2007/08/10 19:39:24 d1mag Exp $
+ * $Id: temploggerd.c,v 1.12 2007/10/12 12:46:48 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -253,9 +253,10 @@ int check_and_create_rrd_files(void)
 	  continue;
 	}
 	if((save_all_sensors || s->file_found_on_bus) && !s->ignored) {
+	  char *rrdtype[3] = { "GAUGE", "COUNTER", "DERIVE" };
 	  rrd_sensid(s, rrdid);
 	  //printf("create [%s]\n", rrdid);
-	  len += sprintf(&cmd[len], " DS:%s:GAUGE:%d:-39.9:256", rrdid, 2*loopdelay);
+	  len += sprintf(&cmd[len], " DS:%s:%s:%d:%d:%d", rrdid, rrdtype[s->rrdtype], 2*loopdelay, s->minval, s->maxval);
 	}
 	if(len > (cmd_len>>1)) {
 	  cmd_len <<= 1;
@@ -679,9 +680,12 @@ int main(int argc, char **argv)
 	  continue;
 	}
 	if((save_all_sensors || s->file_found_on_bus) && !s->ignored) {
-	  if(s->avail)
-	    len += sprintf(&cmd[len], "%.2f:", s->last_temp);
-	  else
+	  if(s->avail) {
+	    if(s->rrdtype == 0)
+	      len += sprintf(&cmd[len], "%.2f:", s->last_value); // GAUGE
+	    else
+	      len += sprintf(&cmd[len], "%ld:", (long)s->last_value); // COUNTER,DERIVE
+	  } else
 	    len += sprintf(&cmd[len], "U:");
 	}
 	if(len > (cmd_len>>1)) {
